@@ -2,7 +2,7 @@ package Net::IPAM::IP;
 
 use strict;
 use warnings;
-our $VERSION = '1.09';
+our $VERSION = '1.10';
 
 use Socket qw/AF_INET AF_INET6/;
 
@@ -116,12 +116,12 @@ sub new {
 
 =head2 clone
 
-Just a blessed shallow copy of the C<< {binary} >> attribute.
+Clone the object.
 
 =cut
 
 sub clone {
-  return bless( { binary => $_[0]->{binary} }, ref $_[0] );
+  return ( ref $_[0] )->new_from_bytes( $_[0]->bytes );
 }
 
 =head2 new_from_bytes
